"use strict";
exports.__esModule = true;
var fs = require("fs");
var path = require("path");
var build_1 = require("./cmd/build");
var doc_1 = require("./cmd/doc");
var help_1 = require("./cmd/help");
var version_1 = require("./cmd/version");
var logger_1 = require("./lib/logger");
var util = require("./lib/util");
var cwd = process.cwd();
var defOpts = {
    cwd: cwd,
    dirname: path.resolve(__dirname, '../'),
    magicNum: '// Built by eustia.',
    data: {},
    enableLog: false,
    debug: false,
    encoding: 'utf8',
    errLog: false,
    packInfo: require('../package.json')
};
var errLogPath = path.resolve(cwd, './eustia-debug.log');
module.exports = {
    build: cmdFactory(build_1["default"]),
    doc: cmdFactory(doc_1["default"]),
    help: cmdFactory(help_1["default"]),
    version: cmdFactory(version_1["default"])
};
function cmdFactory(cmd) {
    return function (options, cb) {
        cb = cb || util.noop;
        options = util.defaults(options, defOpts, cmd.defOpts || {});
        options.cacheDir = path.resolve(options.cwd, 'eustia/cache');
        if (options.enableLog) {
            logger_1["default"].enable();
        }
        if (options.verbose) {
            logger_1["default"].isDebug = true;
        }
        logger_1["default"].debug('Options', options);
        cmd(options, function (err) {
            if (err) {
                logger_1["default"].error(err);
                if (options.errLog) {
                    fs.writeFileSync(errLogPath, logger_1["default"].history(), 'utf-8');
                    process.exit();
                }
            }
            if (options.errLog) {
                fs.exists(errLogPath, function (result) {
                    if (result) {
                        fs.unlink(errLogPath, util.noop);
                    }
                });
            }
            cb(err);
        });
    };
}
